# Generated by Django 5.2.1 on 2025-06-11 10:40

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('base', '0005_initial'),
        ('invoices', '0004_invoicelineitem_charge_item_reference'),
    ]

    operations = [
        migrations.CreateModel(
            name='InvoiceReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_reference_identifier', to='base.identifier')),
                ('invoice', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_reference_invoice', to='invoices.invoice')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
