# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0004_initial'),
        ('base', '0004_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allergyintoleranceasserterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='allergyintoleranceasserterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='allergyintoleranceasserterreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='asserter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter', to='allergyintolerances.allergyintoleranceasserterreference'),
        ),
        migrations.AddField(
            model_name='allergyintolerancereaction',
            name='exposure_route',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_reaction_exposure_route', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintolerancereaction',
            name='manifestation',
            field=models.ManyToManyField(blank=True, related_name='allergy_intolerance_reaction_manifestation', to='observations.observationcodeablereference'),
        ),
        migrations.AddField(
            model_name='allergyintolerancereaction',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='allergy_intolerance_reaction_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='allergyintolerancereaction',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_reaction_substance', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='reaction',
            field=models.ManyToManyField(blank=True, related_name='allergy_intolerance_reaction', to='allergyintolerances.allergyintolerancereaction'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='allergyintolerancerecorderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='recorder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_recorder', to='allergyintolerances.allergyintolerancerecorderreference'),
        ),
    ]
