# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointments', '0002_initial'),
        ('base', '0003_initial'),
        ('careplans', '0003_initial'),
        ('endpoints', '0001_initial'),
        ('imagingselections', '0001_initial'),
        ('imagingstudies', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingselection',
            name='derived_from',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_derived_from', to='imagingstudies.imagingstudyreference'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='endpoint',
            field=models.ManyToManyField(blank=True, related_name='imaging_selection_endpoint', to='endpoints.endpointreference'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='image_selection_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_appointment', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_identifier', to='base.identifier'),
        ),
    ]
