# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllergyIntoleranceReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('allergy_intolerance', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='allergy_intolerance_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='allergy_intolerance_reference_identifier', to='base.identifier')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
