# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('medicationadministrations', '0002_initial'),
        ('medicationdispenses', '0002_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationadministration',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='supporting_information',
            field=models.ManyToManyField(related_name='medication_administration_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='dose',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_dose', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='method',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_method', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='rate_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_rate_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='rate_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_rate_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='route',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_route', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationadministrationdosage',
            name='site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='dosage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_dosage', to='medicationadministrations.medicationadministrationdosage'),
        ),
        migrations.AddField(
            model_name='medicationadministrationpartof',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='medication_administration_part_of_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationadministrationpartof',
            name='medication_administraton',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_part_of_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='medicationadministrationpartof',
            name='medication_dispense',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_part_of_medication_dispense', to='medicationdispenses.medicationdispense'),
        ),
    ]
