# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
        ('devicemetrics', '0001_initial'),
        ('devices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='devicemetric',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_device', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='devicemetric',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='device_metrics_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicemetric',
            name='measurement_frequency',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_measurement_frequency', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='devicemetric',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicemetric',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_unit', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicemetriccalibration',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_calibration_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicemetric',
            name='calibration',
            field=models.ManyToManyField(blank=True, related_name='device_metric_calibration', to='devicemetrics.devicemetriccalibration'),
        ),
        migrations.AddField(
            model_name='devicemetricreference',
            name='device_metric',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_reference', to='devicemetrics.devicemetric'),
        ),
        migrations.AddField(
            model_name='devicemetricreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_reference_identifier', to='base.identifier'),
        ),
    ]
