# Generated by Django 5.2 on 2025-05-06 15:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0004_initial'),
        ('coverages', '0002_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accountcoverage',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_coverage_coverage', to='coverages.coveragereference'),
        ),
    ]
