# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('biologicallyderivedproducts', '0002_initial'),
        ('documentreferences', '0005_initial'),
        ('genomicstudies', '0003_initial'),
        ('imagingselections', '0003_initial'),
        ('imagingstudies', '0002_initial'),
        ('immunizations', '0003_initial'),
        ('medicationadministrations', '0004_initial'),
        ('medicationdispenses', '0003_initial'),
        ('medicationstatements', '0004_initial'),
        ('molecularsequences', '0001_initial'),
        ('nutritionorders', '0004_nutritionorder_allergy_intolerance'),
        ('nutritionproducts', '0001_initial'),
        ('observations', '0003_initial'),
        ('procedures', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='documentreferenceobservationreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='document_reference_observation_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='observationbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_derived_from_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='imaging_selection',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='imagingselections.imagingselection'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='molecular_sequence',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_derived_from_reference_molecular_sequence', to='molecularsequences.molecularsequence'),
        ),
        migrations.AddField(
            model_name='observationhasmemberreference',
            name='molecular_sequence',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_has_member_reference_molecular_sequence', to='molecularsequences.molecularsequence'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='genomic_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_genomic_study', to='genomicstudies.genomicstudy'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='medication_dispense',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_medication_dispense', to='medicationdispenses.medicationdispense'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_subject_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='nutrition_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_subject_reference_nutrition_product', to='nutritionproducts.nutritionproduct'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_subject_reference_procedure', to='procedures.procedure'),
        ),
    ]
