# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0002_initial'),
        ('base', '0003_initial'),
        ('encounters', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allergyintolerance',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='allergy_intolerance_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='allergy_intolerance_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='onset_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_onset_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='onset_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_onset_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='onset_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_onset_range', to='base.range'),
        ),
    ]
