"""Locations app configuration."""

from django.apps import AppConfig


class LocationsConfig(AppConfig):
    """Locations app configuration."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.locations"
