# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careplans', '0004_initial'),
        ('communications', '0002_initial'),
        ('devicerequests', '0002_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('medicationrequests', '0001_initial'),
        ('nutritionorders', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='communication',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='topic',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_topic', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]
