# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('coverageeligibilityresponses', '0001_initial'),
        ('coverages', '0002_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='patient',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseerror',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_error_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='error',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_error', to='coverageeligibilityresponses.coverageeligibilityresponseerror'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseevent',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_event_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_event', to='coverageeligibilityresponses.coverageeligibilityresponseevent'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsurance',
            name='benefit_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_benefit_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_insurance', to='coverageeligibilityresponses.coverageeligibilityresponseinsurance'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='authorization_supporting',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_insurance_item_authorization_supporting', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='modifier',
            field=models.ManyToManyField(related_name='coverage_eligibility_response_insurance_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='network',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_network', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_product_or_service', to='base.codeableconcept'),
        ),
    ]
