# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('diagnosticreports', '0003_initial'),
        ('immunizations', '0002_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='immunization_based_on', to='immunizations.immunizationbasedonreference'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='immunizationinformationsourcerefrence',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source_references', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='information_source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_information_source', to='immunizations.immunizationinformationsourcerefrence'),
        ),
        migrations.AddField(
            model_name='immunizationperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performers', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='immunization_performer', to='immunizations.immunizationperformer'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='immunizationperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performer_actor_references', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='immunizationperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_performers', to='immunizations.immunizationperformeractorreference'),
        ),
        migrations.AddField(
            model_name='immunizationprogrameligibility',
            name='program',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_program_eligibility_program', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationprogrameligibility',
            name='program_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_program_eligibility_program_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='program_eligibility',
            field=models.ManyToManyField(blank=True, related_name='immunization_program_eligibility', to='immunizations.immunizationprogrameligibility'),
        ),
        migrations.AddField(
            model_name='immunizationprotocolapplied',
            name='authority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_protocol_applied_authority', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='immunizationprotocolapplied',
            name='target_disease',
            field=models.ManyToManyField(blank=True, related_name='immunization_protocol_applied_usage_disease', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='protocol_applied',
            field=models.ManyToManyField(blank=True, related_name='immunization_protocol_applied', to='immunizations.immunizationprotocolapplied'),
        ),
        migrations.AddField(
            model_name='immunizationreaction',
            name='manifestation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reaction_detail', to='observations.observationcodeablereference'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='reaction',
            field=models.ManyToManyField(blank=True, related_name='immunization_reaction', to='immunizations.immunizationreaction'),
        ),
        migrations.AddField(
            model_name='immunizationreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_codeable_references_identifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='immunization_reason', to='immunizations.immunizationreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='immunizationreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_references_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='immunizationreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_references_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='immunizationreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_references_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_references_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='immunizationreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_reason_codeable_references_reference', to='immunizations.immunizationreasonreference'),
        ),
    ]
