# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('immunizationevaluations', '0002_initial'),
        ('immunizations', '0004_immunizationreference'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunizationevaluation',
            name='immunization_event',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_evaluation_immunization_event', to='immunizations.immunizationreference'),
        ),
    ]
