# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('coverageeligibilityresponses', '0002_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_provider', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_unit_price', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsurance',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_insurance_item', to='coverageeligibilityresponses.coverageeligibilityresponseinsuranceitem'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitembenefit',
            name='allowed_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_benefit_allowed_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitembenefit',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_benefit_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitembenefit',
            name='used_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_insurance_item_benefit_used_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponseinsuranceitem',
            name='benefit',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_response_insurance_item_benefit', to='coverageeligibilityresponses.coverageeligibilityresponseinsuranceitembenefit'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponserequesterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_requester_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponserequesterreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_requester_reference_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponserequesterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_requester_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponserequesterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_requester_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityresponse',
            name='requestor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_response_requestor', to='coverageeligibilityresponses.coverageeligibilityresponserequesterreference'),
        ),
    ]
