# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('conditions', '0004_initial'),
        ('contracts', '0002_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0003_initial'),
        ('encounters', '0003_initial'),
        ('groups', '0001_initial'),
        ('locations', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='contractauthorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_author_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contractauthorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_author_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contract',
            name='author',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_author', to='contracts.contractauthorreference'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinition',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinition',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contract',
            name='content_definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition', to='contracts.contractcontentdefinition'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinitionpublisherreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_publisher_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinitionpublisherreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_publisher_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinitionpublisherreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_publisher_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinitionpublisherreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_publisher_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contractcontentdefinition',
            name='publisher',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_content_definition_publisher', to='contracts.contractcontentdefinitionpublisherreference'),
        ),
        migrations.AddField(
            model_name='contractfriendly',
            name='content_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_friendly_content_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='contract',
            name='friendly',
            field=models.ManyToManyField(blank=True, related_name='contract_friendly', to='contracts.contractfriendly'),
        ),
        migrations.AddField(
            model_name='contractfriendlycontentreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_friendly_content_reference_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='contractfriendlycontentreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_friendly_content_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractfriendly',
            name='content_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_friendly_content_reference', to='contracts.contractfriendlycontentreferencereference'),
        ),
        migrations.AddField(
            model_name='contractlegal',
            name='content_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legal_content_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='contract',
            name='legal',
            field=models.ManyToManyField(blank=True, related_name='contract_legal', to='contracts.contractlegal'),
        ),
        migrations.AddField(
            model_name='contractlegalcontentreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legal_content_reference_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='contractlegalcontentreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legal_content_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractlegal',
            name='content_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legal_content_reference', to='contracts.contractlegalcontentreferencereference'),
        ),
        migrations.AddField(
            model_name='contractlegallybindingreferencereference',
            name='contract',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legally_binding_reference_reference_contract', to='contracts.contract'),
        ),
        migrations.AddField(
            model_name='contractlegallybindingreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legally_binding_reference_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='contractlegallybindingreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legally_binding_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contract',
            name='legally_binding_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_legally_binding_reference', to='contracts.contractlegallybindingreferencereference'),
        ),
        migrations.AddField(
            model_name='contractreference',
            name='contract',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_reference_contract', to='contracts.contract'),
        ),
        migrations.AddField(
            model_name='contractreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contract',
            name='instantiates_canonical',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_instantiates_canonical', to='contracts.contractreference'),
        ),
        migrations.AddField(
            model_name='contractrule',
            name='content_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_rule_content_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='contract',
            name='rule',
            field=models.ManyToManyField(blank=True, related_name='contract_rule', to='contracts.contractrule'),
        ),
        migrations.AddField(
            model_name='contractsigner',
            name='signature',
            field=models.ManyToManyField(blank=True, related_name='contract_signer_signature', to='base.signature'),
        ),
        migrations.AddField(
            model_name='contractsigner',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_type', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contract',
            name='signer',
            field=models.ManyToManyField(blank=True, related_name='contract_signer', to='contracts.contractsigner'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contractsignerpartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contractsigner',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_signer_party', to='contracts.contractsignerpartyreference'),
        ),
        migrations.AddField(
            model_name='contractsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contract',
            name='subject',
            field=models.ManyToManyField(blank=True, related_name='contract_subject', to='contracts.contractsubjectreference'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='applies',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_applies', to='base.period'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='group',
            field=models.ManyToManyField(blank=True, to='contracts.contractterm'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='topic_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_topic_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='topic_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_topic_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contract',
            name='term',
            field=models.ManyToManyField(blank=True, related_name='contract_term', to='contracts.contractterm'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='context',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_context', to='encounters.encounterepisodeofcarereference'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='intent',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_intent', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='occurrence_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_occurrence_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='occurrence_timing',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_occurrence_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='performer_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='performer_type',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_performer_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='action',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action', to='contracts.contracttermaction'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermactionperformerreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='performer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_performer', to='contracts.contracttermactionperformerreference'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_reason', to='contracts.contracttermactionreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='contracttermactionreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_reason_codeable_reference_reference', to='contracts.contracttermactionreasonreference'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermactionrequesterreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_requester_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='requester',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_requester', to='contracts.contracttermactionrequesterreference'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubject',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermaction',
            name='subject',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_subject', to='contracts.contracttermactionsubject'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubjectreferencereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_action_subject_reference_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermactionsubject',
            name='reference',
            field=models.ManyToManyField(blank=True, related_name='contract_term_action_subject_reference', to='contracts.contracttermactionsubjectreferencereference'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='period',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='period_type',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_period_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_relationship', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='scope',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_scope', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='subtype',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_subtype', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='type_reference',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_type_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='use_period',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_use_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='asset',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset', to='contracts.contracttermasset'),
        ),
        migrations.AddField(
            model_name='contracttermassetcontext',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_context_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermassetcontext',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_context_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='context',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_context', to='contracts.contracttermassetcontext'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='entity_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_entity_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='entity_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_entity_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='valued_item',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_valued_item', to='contracts.contracttermassetvalueditem'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemrecipientreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_recipient_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='recipient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_recipient', to='contracts.contracttermassetvalueditemrecipientreference'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditemresponsiblereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_tem_asset_valued_item_responsible_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermassetvalueditem',
            name='responsible',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_asset_valued_item_responsible', to='contracts.contracttermassetvalueditemresponsiblereference'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='decision',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_decision', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='decision_mode',
            field=models.ManyToManyField(blank=True, related_name='contract_term_offer_decision_mode', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='contract_term_offer_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='topic',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_topic', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='offer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer', to='contracts.contracttermoffer'),
        ),
        migrations.AddField(
            model_name='contracttermofferanswer',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_answer_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='contracttermofferanswer',
            name='value_coding',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_answer_coding', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contracttermofferanswer',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_answer_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='contracttermofferanswer',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_answer_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='answer',
            field=models.ManyToManyField(blank=True, related_name='contract_term_offer_answer', to='contracts.contracttermofferanswer'),
        ),
        migrations.AddField(
            model_name='contracttermasset',
            name='answer',
            field=models.ManyToManyField(blank=True, related_name='contract_term_asset_answer', to='contracts.contracttermofferanswer'),
        ),
        migrations.AddField(
            model_name='contracttermofferparty',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='contracttermoffer',
            name='party',
            field=models.ManyToManyField(blank=True, related_name='contract_term_offer_party', to='contracts.contracttermofferparty'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='contracttermofferpartyreferencereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_offer_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='contracttermofferparty',
            name='reference',
            field=models.ManyToManyField(blank=True, related_name='contract_term_offer_party_reference', to='contracts.contracttermofferpartyreferencereference'),
        ),
        migrations.AddField(
            model_name='contracttermsecuritylabel',
            name='category',
            field=models.ManyToManyField(blank=True, related_name='contract_term_security_label_category', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contracttermsecuritylabel',
            name='classification',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contract_term_security_label_classification', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contracttermsecuritylabel',
            name='control',
            field=models.ManyToManyField(blank=True, related_name='contract_term_security_label_control', to='base.coding'),
        ),
        migrations.AddField(
            model_name='contractterm',
            name='security_label',
            field=models.ManyToManyField(blank=True, related_name='contract_term_security_label', to='contracts.contracttermsecuritylabel'),
        ),
    ]
