# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('explanationofbenefits', '0002_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='explanationofbenefit',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='pre_auth_period',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_priority', to='base.codeableconcept'),
        ),
    ]
