# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0003_initial'),
        ('base', '0003_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allergyintolerance',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='verification_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_verification_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintoleranceasserterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='allergyintoleranceasserterreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_asserter_reference_patient', to='patients.patient'),
        ),
    ]
