# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0007_initial'),
        ('appointments', '0003_initial'),
        ('base', '0005_initial'),
        ('careplans', '0004_initial'),
        ('careteams', '0004_initial'),
        ('claims', '0003_initial'),
        ('contracts', '0003_initial'),
        ('coverageeligibilityrequests', '0002_initial'),
        ('devicerequests', '0004_initial'),
        ('devices', '0001_initial'),
        ('documentreferences', '0003_initial'),
        ('enrollmentrequests', '0003_initial'),
        ('groups', '0001_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('medicationrequests', '0001_initial'),
        ('nutritionorders', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='documentreferenceattesterpartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_attester_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='documentreferenceattesterpartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_attester_party_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='documentreferenceattesterpartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_attester_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='documentreferenceattester',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_attesters_party', to='documentreferences.documentreferenceattesterpartyreference'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_references_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='documentreferenceauthorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_author_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='documentreference',
            name='author',
            field=models.ManyToManyField(blank=True, related_name='document_reference_authors', to='documentreferences.documentreferenceauthorreference'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_appointment', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='appointment_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_appointment_response', to='appointmentresponses.appointmentresponse'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_claim', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='contract',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_contract', to='contracts.contract'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='coverage_eligibility_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_coverage_eligibility_request', to='coverageeligibilityrequests.coverageeligibilityrequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='enrollment_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_enrollment_request', to='enrollmentrequests.enrollmentrequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_references_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]
