# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('groups', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingselections', '0002_initial'),
        ('medications', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='image_selection_based_on', to='imagingselections.imagingselectionbasedonreference'),
        ),
        migrations.AddField(
            model_name='imagingselectioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='image_region_3d',
            field=models.ManyToManyField(blank=True, related_name='image_selection_image_region_3d', to='imagingselections.imagingselectionimageregion3d'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='instance',
            field=models.ManyToManyField(blank=True, related_name='image_selection_instance', to='imagingselections.imagingselectioninstance'),
        ),
        migrations.AddField(
            model_name='imagingselectioninstance',
            name='imaging_region_2d',
            field=models.ManyToManyField(blank=True, related_name='image_selection_instance_imaging_region_2d', to='imagingselections.imagingselectioninstanceimagingregion2d'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='image_selection_performer', to='imagingselections.imagingselectionperformer'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_care_team', to='careteams.careteamreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_performer_actor', to='imagingselections.imagingselectionperformeractorreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionreference',
            name='image_selection',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_reference_image_selection', to='imagingselections.imagingselection'),
        ),
        migrations.AddField(
            model_name='imagingselectioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_codeable_reference_reference', to='imagingselections.imagingselectionreference'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='focus',
            field=models.ManyToManyField(blank=True, related_name='imaging_selection_focus', to='imagingselections.imagingselectionreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_subject', to='imagingselections.imagingselectionsubjectreference'),
        ),
    ]
