# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('chargeitems', '0003_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0002_initial'),
        ('medicationadministrations', '0003_initial'),
        ('medicationdispenses', '0002_initial'),
        ('medicationrequests', '0002_initial'),
        ('medications', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('substances', '0001_initial'),
        ('supplydeliveries', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chargeitementererreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer', to='chargeitems.chargeitementererreference'),
        ),
        migrations.AddField(
            model_name='chargeitemperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='charge_item_performer', to='chargeitems.chargeitemperformer'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='chargeitemperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor', to='chargeitems.chargeitemperformeractorreference'),
        ),
        migrations.AddField(
            model_name='chargeitemproductcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='product',
            field=models.ManyToManyField(blank=True, related_name='charge_item_product', to='chargeitems.chargeitemproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='chargeitemproductcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_codeable_reference_reference', to='chargeitems.chargeitemproductreference'),
        ),
        migrations.AddField(
            model_name='chargeitemreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='charge_item_reason', to='chargeitems.chargeitemreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitemreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_codeable_reference_reference', to='chargeitems.chargeitemreasonreference'),
        ),
        migrations.AddField(
            model_name='chargeitemservicecodealbereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='service',
            field=models.ManyToManyField(blank=True, related_name='charge_item_service', to='chargeitems.chargeitemservicecodealbereference'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_dispense',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_dispense', to='medicationdispenses.medicationdispense'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='supply_delivery',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_supply_delivery', to='supplydeliveries.supplydelivery'),
        ),
        migrations.AddField(
            model_name='chargeitemservicecodealbereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_codeable_reference_reference', to='chargeitems.chargeitemservicereference'),
        ),
        migrations.AddField(
            model_name='charitemreference',
            name='charge_item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reference_charge_item', to='chargeitems.chargeitem'),
        ),
        migrations.AddField(
            model_name='charitemreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='charge_item_reference_part_of', to='chargeitems.charitemreference'),
        ),
    ]
