# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('bodystructures', '0002_initial'),
        ('claimresponses', '0002_initial'),
        ('claims', '0002_initial'),
        ('locations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claimresponse',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='payee_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='pre_auth_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_request', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='provider_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='add_item',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item', to='claimresponses.claimresponseadditem'),
        ),
        migrations.AddField(
            model_name='claimresponseadditembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='claimresponseadditembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site', to='claimresponses.claimresponseadditembodysite'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail', to='claimresponses.claimresponseadditemdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail', to='claimresponses.claimresponseadditemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_organization', to='base.organizationreference'),
        ),
    ]
