# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0001_initial'),
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allergyintolerance',
            name='clinical_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_clinical_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_code', to='base.codeableconcept'),
        ),
    ]
