# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_request', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='storage_temp_requirements',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_storage_temp_requirements', to='base.range'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='collected_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_collected_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='collector',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_collector', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_source', to='patients.patientorganizationreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='collection',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_collection', to='biologicallyderivedproducts.biologicallyderivedproductcollection'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='property',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_property', to='biologicallyderivedproducts.biologicallyderivedproductproperty'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='parent',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_parent', to='biologicallyderivedproducts.biologicallyderivedproductreference'),
        ),
    ]
