# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('medicationknowledges', '0001_initial'),
        ('medications', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medication',
            name='definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_definition', to='medicationknowledges.medicationknowledgereference'),
        ),
        migrations.AddField(
            model_name='medicationsubstancereference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_substance_reference_substance', to='substances.substance'),
        ),
    ]
