# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('coverages', '0002_initial'),
        ('devicerequests', '0004_initial'),
        ('supplyrequests', '0001_initial'),
        ('tasks', '0001_initial'),
        ('transports', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='transport',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='transport_insurance', to='coverages.coverageclaimresponsereference'),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='display',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='reference',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='supply_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_supply_request', to='supplyrequests.supplyrequest'),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_task', to='tasks.task'),
        ),
        migrations.AddField(
            model_name='transportbasedonreference',
            name='type',
            field=models.CharField(max_length=255, null=True),
        ),
    ]
