# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('chargeitems', '0005_rename_charitemreference_chargeitemreference'),
        ('invoices', '0003_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoicelineitem',
            name='charge_item_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_line_item_charge_item_reference', to='chargeitems.chargeitemreference'),
        ),
    ]
