# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('careteams', '0001_initial'),
        ('conditions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='careteam',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='care_teams_reason_code', to='conditions.conditioncodeablereference'),
        ),
    ]
