# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('locations', '0001_initial'),
        ('medicationdispenses', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationdispense',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_part_of', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_performer', to='medicationdispenses.medicationdispenseperformer'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='devices.device'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='patients.patient'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='medicationdispenseperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_performer_actor', to='medicationdispenses.medicationdispenseperformeractorreference'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='locations.location'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='patients.patient'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationdispensereceiverreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='receiver',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_receiver', to='medicationdispenses.medicationdispensereceiverreference'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitution',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_substitution_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitution',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_substitution_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='substitution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_substitution', to='medicationdispenses.medicationdispensesubstitution'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitutionresponsiblepartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitutionresponsiblepartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitutionresponsiblepartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitutionresponsiblepartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationdispensesubstitution',
            name='responsible_party',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_substitution_responsible_party', to='medicationdispenses.medicationdispensesubstitutionresponsiblepartyreference'),
        ),
    ]
