# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0003_initial'),
        ('base', '0005_initial'),
        ('encounters', '0003_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('paymentreconciliations', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentreconciliationallocation',
            name='responsible',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_reconciliation_allocation_responsible', to='practitionerroles.practitionerrolereference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocation',
            name='submitter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_submitter', to='paymentreconciliations.organizationpractitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocation',
            name='target_item_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_item_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocation',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='paymentreconciliation',
            name='allocation',
            field=models.ManyToManyField(blank=True, related_name='payment_reconciliation_allocation', to='paymentreconciliations.paymentreconciliationallocation'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_account', to='accounts.account'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_encounter', to='encounters.encounter'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_reconciliation_allocation_target_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocation',
            name='target',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target', to='paymentreconciliations.paymentreconciliationallocationtargetreference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationpaymentissuerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_reconciliation_payment_issuer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationpaymentissuerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_payment_issuer_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationpaymentissuerreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_payment_issuer_reference_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationpaymentissuerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_payment_issuer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='paymentreconciliation',
            name='payment_issuer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_payment_issuer', to='paymentreconciliations.paymentreconciliationpaymentissuerreference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliation',
            name='process_note',
            field=models.ManyToManyField(blank=True, related_name='payment_reconciliation_process_note', to='paymentreconciliations.paymentreconciliationprocessnote'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationreference',
            name='payment_reconciliation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_reference_payment_reconciliation', to='paymentreconciliations.paymentreconciliation'),
        ),
    ]
