# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('detectedissues', '0001_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='detectedissue',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='detectedissue',
            name='identified_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.period'),
        ),
        migrations.AddField(
            model_name='detectedissue',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='detected_issue_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='detectedissue',
            name='implicated',
            field=models.ManyToManyField(blank=True, related_name='detected_issue_implicated', to='base.reference'),
        ),
        migrations.AddField(
            model_name='detectedissueauthorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_author_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='detectedissueauthorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_author_reference_identifier', to='base.identifier'),
        ),
    ]
