# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('clinicalimpressions', '0002_initial'),
        ('conditions', '0003_initial'),
        ('documentreferences', '0003_initial'),
        ('observations', '0002_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='clinicalimpression',
            name='performer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_performer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='problem',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_problem', to='conditions.conditionallergyintolerancereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='prognosis_codeable_concept',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_prognosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_supporting_info', to='base.reference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='finding',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_finding', to='clinicalimpressions.clinicalimpressionfinding'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfinding',
            name='item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item', to='clinicalimpressions.clinicalimpressionfindingitemcodeablereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionfindingitemcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_finding_item_codeable_reference_reference', to='clinicalimpressions.clinicalimpressionfindingitemreference'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionreference',
            name='clinical_impression',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_reference_clinical_impression', to='clinicalimpressions.clinicalimpression'),
        ),
        migrations.AddField(
            model_name='clinicalimpressionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='previous',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_previous', to='clinicalimpressions.clinicalimpressionreference'),
        ),
    ]
