# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('devicerequests', '0003_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0003_initial'),
        ('groups', '0001_initial'),
        ('locations', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='devicerequestperformerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='devicerequestperformercodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_performer_codeable_reference_reference', to='devicerequests.devicerequestperformerreference'),
        ),
        migrations.AddField(
            model_name='devicerequestreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='device_request_reason', to='devicerequests.devicerequestreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='devicerequestreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='devicerequestreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='devicerequestreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='devicerequestreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequestreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='devicerequestreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reason_codeable_reference_reference', to='devicerequests.devicerequestreasonreference'),
        ),
        migrations.AddField(
            model_name='devicerequestreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='devicerequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='replaces',
            field=models.ManyToManyField(blank=True, related_name='device_request_replaces', to='devicerequests.devicerequestreference'),
        ),
        migrations.AddField(
            model_name='devicerequestrequestercodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_codeable_reference_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='devicerequestrequesterreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='devicerequestrequesterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequestrequesterreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='devicerequestrequesterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='devicerequestrequesterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='devicerequestrequestercodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester_codeable_reference_reference', to='devicerequests.devicerequestrequesterreference'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='requester',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_requester', to='devicerequests.devicerequestrequesterreference'),
        ),
        migrations.AddField(
            model_name='devicerequestsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='devicerequestsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='devicerequestsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='devicerequestsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='devicerequestsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='devicerequest',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_request_subject', to='devicerequests.devicerequestsubjectreference'),
        ),
    ]
