# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('bodystructures', '0001_initial'),
        ('devices', '0001_initial'),
        ('imagingselections', '0002_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='bodystructure',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='body_structure_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='bodystructurecodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='bodystructurereference',
            name='body_structure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bodystructures.bodystructure'),
        ),
        migrations.AddField(
            model_name='bodystructurereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='bodystructurecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bodystructures.bodystructurereference'),
        ),
        migrations.AddField(
            model_name='distancefromlandmark',
            name='device',
            field=models.ManyToManyField(blank=True, related_name='distance_from_landmark_device', to='devices.devicecodeablereference'),
        ),
        migrations.AddField(
            model_name='distancefromlandmark',
            name='value',
            field=models.ManyToManyField(blank=True, related_name='distance_from_landmark_value', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='bodylandmarkorientation',
            name='distance_from_landmark',
            field=models.ManyToManyField(blank=True, related_name='body_landmark_orientation_distance_from_landmark', to='bodystructures.distancefromlandmark'),
        ),
        migrations.AddField(
            model_name='includedstructure',
            name='body_landmark_orientation',
            field=models.ManyToManyField(blank=True, related_name='included_structure_body_landmark_orientation', to='bodystructures.bodylandmarkorientation'),
        ),
        migrations.AddField(
            model_name='includedstructure',
            name='laterality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='included_structure_laterality', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='includedstructure',
            name='qualifier',
            field=models.ManyToManyField(blank=True, related_name='included_structure_qualifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='includedstructure',
            name='spatial_reference',
            field=models.ManyToManyField(blank=True, related_name='included_structure_spatial_reference', to='imagingselections.imagingselectionreference'),
        ),
        migrations.AddField(
            model_name='includedstructure',
            name='structure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='included_structure_structure', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='bodystructure',
            name='excluded_structure',
            field=models.ManyToManyField(blank=True, related_name='body_structure_excluded_structure', to='bodystructures.includedstructure'),
        ),
        migrations.AddField(
            model_name='bodystructure',
            name='included_structure',
            field=models.ManyToManyField(blank=True, related_name='body_structure_included_structure', to='bodystructures.includedstructure'),
        ),
    ]
