# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careplans', '0004_initial'),
        ('nutritionintakes', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionintake',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='nutritionintakebasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='nutritionintakebasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_based_on_reference_identifier', to='base.identifier'),
        ),
    ]
