# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('communications', '0002_initial'),
        ('diagnosticreports', '0001_initial'),
        ('encounters', '0002_initial'),
        ('observations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='conclusioncodereference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='conclusion_code_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='conclusioncodecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='conclusion_code_codeable_reference_codeable', to='diagnosticreports.conclusioncodereference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='category',
            field=models.ManyToManyField(blank=True, related_name='diagnostics_report_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostics_report_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='communication',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_communication', to='communications.communicationreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='conclusion_code',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_conclusion_code', to='diagnosticreports.conclusioncodecodeablereference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='effective_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_effective_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='presented_form',
            field=models.ManyToManyField(blank=True, to='base.attachment'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='recommendation',
            field=models.ManyToManyField(blank=True, to='base.codeablereference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='result',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_result', to='observations.observationreference'),
        ),
    ]
