# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0004_initial'),
        ('base', '0004_initial'),
        ('conditions', '0002_initial'),
        ('devices', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='condition',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='condition',
            name='verification_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_verification_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionallergyintolerancereference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_allergy_intolerance_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='conditionallergyintolerancereference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_allergy_intolerance_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='conditionallergyintolerancereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_allergy_intolerance_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_patient', to='patients.patient'),
        ),
    ]
