# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('medicationrequests', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationrequest',
            name='recorder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_recorder', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='medicationrequest',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationrequest',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='medicationrequest',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='medication_request_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='medicationrequestbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_based_on_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationrequestbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_based_on_reference', to='medicationrequests.medicationrequest'),
        ),
    ]
