# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('genomicstudies', '0001_initial'),
        ('observations', '0002_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='genomicstudy',
            name='interpreter',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_interpreter', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_reason', to='conditions.conditionobservationcodeablereference'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='referrer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_referrer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='change_type',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_change_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='focus',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_focus', to='base.reference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='genomic_build',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_genomic_build', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='method_type',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_method_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_called',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_called', to='observations.documentreferenceobservationreference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_studied',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_studied', to='observations.documentreferenceobservationreference'),
        ),
    ]
