# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('devices', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('schedules', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_related_person', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='signature',
            name='on_behalf_of',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of', to='base.signatureonbehalfofreference'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='signaturewhoreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who_reference_related_person', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='signature',
            name='who',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_who', to='base.signaturewhoreference'),
        ),
        migrations.AddField(
            model_name='timing',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='timing_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='timing',
            name='repeat',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='timing_repeat', to='base.repeat'),
        ),
        migrations.AddField(
            model_name='triggerdefinition',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='trigger_definition_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='triggerdefinition',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='trigger_definition_condition', to='base.expression'),
        ),
        migrations.AddField(
            model_name='triggerdefinition',
            name='timing_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='trigger_definition_timing_reference', to='schedules.schedulereference'),
        ),
        migrations.AddField(
            model_name='triggerdefinition',
            name='timing_timing',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='trigger_definition_timing_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='usagecontext',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='usage_context_code', to='base.coding'),
        ),
        migrations.AddField(
            model_name='usagecontext',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='usage_context_value', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='usagecontext',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='usage_context_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='usagecontext',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='usage_context_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='virtualservicedetailaddress',
            name='address_contact_point',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='virtual_service_detail_address_contact_point', to='base.contactpoint'),
        ),
        migrations.AddField(
            model_name='virtualservicedetailaddress',
            name='address_extended_contact_detail',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='virtual_service_detail_address_extended_contact_detail', to='base.extendedcontactdetail'),
        ),
        migrations.AddField(
            model_name='virtualservicedetails',
            name='address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='virtual_service_details_address', to='base.virtualservicedetailaddress'),
        ),
        migrations.AddField(
            model_name='virtualservicedetails',
            name='channel_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='virtual_service_details_channel_type', to='base.coding'),
        ),
    ]
