# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('medicationrequests', '0001_initial'),
        ('molecularsequences', '0001_initial'),
        ('observations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='observation',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_specimen', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='observation_value', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='molecularsequences.molecularsequencereference'),
        ),
        migrations.AddField(
            model_name='documentreferenceobservationreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='document_reference_observation_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='observationbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
    ]
