# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devicedefinitions', '0001_initial'),
        ('groups', '0003_initial'),
        ('nutritionorders', '0002_initial'),
        ('nutritionproducts', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_based_on', to='nutritionorders.nutritionorderbasedonreference'),
        ),
        migrations.AddField(
            model_name='nutritionordercodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='delivery_Device',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_delivery_device', to='devicedefinitions.devicedefinitioncodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='max_volume_to_administer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_max_volume_to_administer', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='route_of_administration',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_route_of_administration', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='enteral_formula',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enteral_formula', to='nutritionorders.nutritionorderenteralformula'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='rate_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_rate_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='rate_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_rate_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformula',
            name='administration',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_enternal_formula_administration', to='nutritionorders.nutritionorderenteralformulaadministration'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='type',
            field=models.ManyToManyField(related_name='nutrition_order_oral_diet_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='oral_diet',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet', to='nutritionorders.nutritionorderoraldiet'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldietnutrient',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_nutrient_amount', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldietnutrient',
            name='modifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_nutrient_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='nutrient',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_nutrient', to='nutritionorders.nutritionorderoraldietnutrient'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiettexture',
            name='modifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_texture_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiettexture',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_texture_food_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='texture',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_texture', to='nutritionorders.nutritionorderoraldiettexture'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='nutritionorderperformerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_performer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_performer', to='nutritionorders.nutritionorderperformerreference'),
        ),
        migrations.AddField(
            model_name='nutritionorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='nutritionordercodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_codeable_reference_reference', to='nutritionorders.nutritionorderreference'),
        ),
        migrations.AddField(
            model_name='nutritionorderschedule',
            name='as_needed_for',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_oral_diet_schedule_as_needed_for', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionorderschedule',
            name='timing',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_oral_diet_schedule_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='nutritionorderoraldiet',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_oral_diet_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionorderenteralformulaadministration',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_enternal_formula_administration_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='caloric_density',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_caloric_density', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_supplement_schedule', to='nutritionorders.nutritionorderschedule'),
        ),
        migrations.AddField(
            model_name='nutritionordersupplement',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_supplement_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='supplement',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_supplement', to='nutritionorders.nutritionordersupplement'),
        ),
    ]
