# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('goals', '0003_initial'),
        ('groups', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('riskassessments', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='goaladdressesreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='risk_assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_risk_assessment', to='riskassessments.riskassessment'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='goal',
            name='addresses',
            field=models.ManyToManyField(blank=True, related_name='goal_addresses', to='goals.goaladdressesreference'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='goalsourcereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_source_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='goal',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_source', to='goals.goalsourcereference'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='goalsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='goal',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_subject', to='goals.goalsubjectreference'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='detail_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_detail_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='due_duration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_due_duration', to='base.duration'),
        ),
        migrations.AddField(
            model_name='goaltarget',
            name='measure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_target_measure', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='goal',
            name='target',
            field=models.ManyToManyField(blank=True, related_name='goal_target', to='goals.goaltarget'),
        ),
    ]
