# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('chargeitems', '0002_initial'),
        ('conditions', '0002_initial'),
        ('diagnosticreports', '0002_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('observations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chargeitem',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='charge_item_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='total_price_component',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_total_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='unit_price_component',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_unit_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='chargeitementererreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_observation', to='observations.observation'),
        ),
    ]
