# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('claimresponses', '0002_initial'),
        ('contracts', '0001_initial'),
        ('coverages', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='coverage',
            name='beneficiary',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_beneficiary', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='contract',
            field=models.ManyToManyField(blank=True, related_name='coverage_contract', to='contracts.contractreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_insurer', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='subscriber',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_subscriber', to='patients.patientrelatedpersonreference'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='subscriber_identifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_subscriber_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_claim_response', to='claimresponses.claimresponse'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='coverageclaimresponsereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_claim_response_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageclass',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_class_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageclass',
            name='value',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_class_value', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='klass',
            field=models.ManyToManyField(blank=True, related_name='coverage_class', to='coverages.coverageclass'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='network',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_network', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_unit', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='value_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_value_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_value_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='cost_to_beneficiary',
            field=models.ManyToManyField(blank=True, related_name='coverage_cost_to_beneficiary', to='coverages.coveragecosttobeneficiary'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiaryexception',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_exception_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiaryexception',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_cost_to_beneficiary_exception_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coveragecosttobeneficiary',
            name='exception',
            field=models.ManyToManyField(blank=True, related_name='coverage_cost_to_beneficiary_exception', to='coverages.coveragecosttobeneficiaryexception'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='payment_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_payment_by', to='coverages.coveragepaymentby'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='coveragepaymentbypartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_by_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='coveragepaymentby',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_payment_by_party', to='coverages.coveragepaymentbypartyreference'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='coveragepolicyholderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='policy_holder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='coverage',
            name='policy_holder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_policy_holder', to='coverages.coveragepolicyholderreference'),
        ),
        migrations.AddField(
            model_name='coveragereference',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_reference_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='coveragereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='coverage_reference_identifier', to='base.identifier'),
        ),
    ]
