# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('organizations', '0001_initial'),
        ('paymentnotices', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentnoticepayeereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_payee_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='paymentnoticepayeereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_payee_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticepayeereference'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='paymentnoticereporterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_reporter_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='reporter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticereporterreference'),
        ),
        migrations.AddField(
            model_name='paymentnoticerequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_request_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticerequestreference'),
        ),
        migrations.AddField(
            model_name='paymentnoticeresponsereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_response_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='paymentnotice',
            name='response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentnotices.paymentnoticeresponsereference'),
        ),
    ]
