# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careplans', '0004_initial'),
        ('nutritionorders', '0001_initial'),
        ('nutritionproducts', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionorder',
            name='orderer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_orderer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_order_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='nutritionorderadditive',
            name='modular_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_additive_modular_type', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionorderadditive',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_additive_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionorder',
            name='additive',
            field=models.ManyToManyField(blank=True, related_name='nutrition_order_additive', to='nutritionorders.nutritionorderadditive'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionorderbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='nutrition_order_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]
