# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('clinicalimpressions', '0003_initial'),
        ('conditions', '0003_initial'),
        ('diagnosticreports', '0002_initial'),
        ('observations', '0002_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='conditionasserterreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='conditionasserterreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='condition',
            name='asserter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_asserter', to='conditions.conditionasserterreference'),
        ),
        migrations.AddField(
            model_name='conditioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionobservationcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionobservationreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='conditionobservationcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_observation_codeable_reference', to='conditions.conditionobservationreference'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='conditionrecorderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='condition',
            name='recorder',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_recorder', to='conditions.conditionrecorderreference'),
        ),
        migrations.AddField(
            model_name='conditionreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_reference', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='conditionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_codeable_reference', to='conditions.conditionreference'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='summary',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_summary', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='condition',
            name='stage',
            field=models.ManyToManyField(blank=True, related_name='condition_stage', to='conditions.conditionstage'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='clinical_impression',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_clinical_impression', to='clinicalimpressions.clinicalimpression'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='conditionstageassessmentreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='condition_stage_assessment_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='conditionstage',
            name='assessment',
            field=models.ManyToManyField(blank=True, related_name='condition_stage_assessment', to='conditions.conditionstageassessmentreference'),
        ),
    ]
