# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0007_initial'),
        ('appointments', '0004_initial'),
        ('base', '0005_initial'),
        ('bodystructures', '0002_initial'),
        ('careplans', '0005_initial'),
        ('careteams', '0004_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0003_initial'),
        ('documentreferences', '0005_initial'),
        ('endpoints', '0001_initial'),
        ('groups', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingstudy',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_part_of', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='referrer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_referrer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='appointment_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='appointmentresponses.appointmentresponse'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudybasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_based_on_reference', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_based_on', to='imagingstudies.imagingstudybasedonreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyprocedurereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_procedure_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_procedure', to='imagingstudies.imagingstudyprocedurereference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reason', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_reason', to='imagingstudies.imagingstudyreasonreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyreference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_reference_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='body_site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='endpoint',
            field=models.ManyToManyField(related_name='imaging_study_series_endpoint', to='endpoints.endpointreference'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='laterality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_laterality', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='modality',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_modality', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='specimen',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_specimen', to='specimens.specimenreference'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='series',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series', to='imagingstudies.imagingstudyseries'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='instance',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_instance', to='imagingstudies.imagingstudyseriesinstance'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingstudyseries',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='imaging_study_series_performer', to='imagingstudies.imagingstudyseriesperformer'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='imagingstudyseriesperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_series_performer_reference', to='imagingstudies.imagingstudyseriesperformeractorreference'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='groups.group'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingstudysubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject_reference', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='imagingstudy',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_subject', to='imagingstudies.imagingstudysubjectreference'),
        ),
    ]
