{% extends "account/base_manage.html" %}
{% block main %}
    <div class="card">
        <div class="card-body">
            {% block content %}
            {% endblock content %}
        </div>
    </div>
{% endblock main %}
