# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('activitydefinitions', '0008_initial'),
        ('base', '0005_initial'),
        ('groups', '0002_initial'),
        ('medications', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipant',
            name='type_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference', to='activitydefinitions.activitydefinitionparticipanttypereference'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='activitydefinitionproductproductreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_product_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='activitydefinition',
            name='product_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_product_reference', to='activitydefinitions.activitydefinitionproductproductreference'),
        ),
        migrations.AddField(
            model_name='activitydefinitionreference',
            name='activity_definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_reference', to='activitydefinitions.activitydefinition'),
        ),
        migrations.AddField(
            model_name='activitydefinitionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinitionsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='activitydefinitionsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinition',
            name='subject_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_subject_reference', to='activitydefinitions.activitydefinitionsubjectreference'),
        ),
    ]
