# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('chargeitems', '0004_initial'),
        ('claims', '0004_initial'),
        ('contracts', '0003_initial'),
        ('invoices', '0003_initial'),
        ('paymentreconciliations', '0002_initial'),
        ('tasks', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentreconciliation',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_request', to='tasks.taskreference'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='charge_item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_charge_item', to='chargeitems.chargeitem'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_claim', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='contract',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_contract', to='contracts.contract'),
        ),
        migrations.AddField(
            model_name='paymentreconciliationallocationtargetreference',
            name='invoice',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='payment_reconciliation_allocation_target_reference_invoice', to='invoices.invoice'),
        ),
    ]
