# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('bodystructures', '0002_initial'),
        ('claims', '0003_initial'),
        ('coverages', '0002_initial'),
        ('devicerequests', '0004_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0003_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('nutritionorders', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('supplyrequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claim',
            name='referral',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_referral', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='total',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_total', to='base.money'),
        ),
        migrations.AddField(
            model_name='claim',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claim',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimaccident',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='accident',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_accident', to='claims.claimaccident'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='specialty',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_specialty', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='claim_care_team', to='claims.claimcareteam'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimcareteamproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimcareteam',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_care_team_provider', to='claims.claimcareteamproviderreference'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='diagnosis_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_diagnosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='diagnosis_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_diagnosis_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='on_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_diagnosis_on_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimdiagnosis',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='claim_diagnosis_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='claim_diagnosis', to='claims.claimdiagnosis'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimentererreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='claim',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_enterer', to='claims.claimentererreference'),
        ),
        migrations.AddField(
            model_name='claimevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_event_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claim',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='claim_event', to='claims.claimevent'),
        ),
        migrations.AddField(
            model_name='claiminsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='claiminsurance',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_insurance_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claim',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='claim_insurance', to='claims.claiminsurance'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='encounter',
            field=models.ManyToManyField(blank=True, related_name='claim_item_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claim',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='claim_item', to='claims.claimitem'),
        ),
        migrations.AddField(
            model_name='claimitembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='claimitembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='claim_item_body_site', to='claims.claimitembodysite'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail', to='claims.claimitemdetail'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claimitemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimitemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='claim_item_detail_sub_detail', to='claims.claimitemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='supply_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_supply_request', to='supplyrequests.supplyrequest'),
        ),
        migrations.AddField(
            model_name='claimitemrequestreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_item_request_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claimitem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='claim_item_request', to='claims.claimitemrequestreference'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimoriginalprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claim',
            name='original_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_original_prescription', to='claims.claimoriginalprescriptionreference'),
        ),
        migrations.AddField(
            model_name='claimpayee',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee', to='claims.claimpayee'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimpayeepartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='claimpayee',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_payee_party', to='claims.claimpayeepartyreference'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claim',
            name='prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_prescription', to='claims.claimprescriptionreference'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='procedure_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_procedure_procedure_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='procedure_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_procedure_procedure_reference', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimprocedure',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='claim_procedure', to='claims.claimprocedure'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claim',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_provider', to='claims.claimproviderreference'),
        ),
        migrations.AddField(
            model_name='claimreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_reference_claim', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='claimreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_claim', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimrelated',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_related_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='claim_related', to='claims.claimrelated'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='timing_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_timing_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='claimsupportinginfo',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_supporting_info_value_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='claim_supporting_info', to='claims.claimsupportinginfo'),
        ),
    ]
