# Generated by Django 5.2.1 on 2025-07-21 00:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('activitydefinitions', '0011_alter_activitydefinition_kind'),
        ('base', '0005_initial'),
        ('plandefinitions', '0003_initial'),
        ('servicerequests', '0002_rename_medicatoin_request_servicerequestbasedonreference_medication_request_and_more'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ActivityPlanDefinitionReference',
            new_name='ActivityDefinitionPlanDefinitionReference',
        ),
    ]
