# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointments', '0002_initial'),
        ('base', '0005_initial'),
        ('careplans', '0004_initial'),
        ('devicerequests', '0004_initial'),
        ('medicationrequests', '0001_initial'),
        ('nutritionorders', '0001_initial'),
        ('patients', '0002_initial'),
        ('slots', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointment',
            name='slot',
            field=models.ManyToManyField(blank=True, related_name='appointment_slot', to='slots.slotreference'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='specialty',
            field=models.ManyToManyField(blank=True, related_name='appointment_specialty', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='appointment_supporting_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='virtual_service',
            field=models.ManyToManyField(blank=True, related_name='appointment_virtual_service_details', to='base.virtualservicedetails'),
        ),
        migrations.AddField(
            model_name='appointmentbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_based_on_reference_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='appointmentbasedonreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_based_on_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='appointmentbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='appointmentbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='appointmentbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_based_on_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]
