# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('groups', '0003_initial'),
        ('plandefinitions', '0002_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='plandefinitionactoroptiontypereferencereference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='plan_definition_actor_option_type_reference_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='plandefinitionactoroptiontypereferencereference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='plan_definition_actor_option_type_reference_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='plandefinitionactionparticipant',
            name='type_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_action_participant_type_reference', to='plandefinitions.plandefinitionactoroptiontypereferencereference'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='addresses',
            field=models.ManyToManyField(related_name='plan_definition_goal_addresses', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='description',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_description', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='documentation',
            field=models.ManyToManyField(related_name='plan_definition_goal_documentation', to='base.relatedartifact'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_priority', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='start',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_start', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinition',
            name='goal',
            field=models.ManyToManyField(blank=True, related_name='plan_definition_goal', to='plandefinitions.plandefinitiongoal'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='detail_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_detail_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='detail_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_detail_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='detail_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_detail_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='detail_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_detail_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='due',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_due', to='base.period'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoaltarget',
            name='measure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_goal_target_measure', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefinitiongoal',
            name='target',
            field=models.ManyToManyField(related_name='plan_definition_goal_target', to='plandefinitions.plandefinitiongoaltarget'),
        ),
        migrations.AddField(
            model_name='plandefinitionsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='plan_definition_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='plandefinitionsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='plan_definition_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='plandefinition',
            name='subject_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_subject_reference', to='plandefinitions.plandefinitionsubjectreference'),
        ),
        migrations.AddField(
            model_name='plandefintionactoroption',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_actor_option_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='plandefintionactoroption',
            name='type_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='plan_definition_actor_option_type_reference', to='plandefinitions.plandefinitionactoroptiontypereferencereference'),
        ),
        migrations.AddField(
            model_name='plandefinitionactor',
            name='option',
            field=models.ManyToManyField(related_name='plan_definition_actor_option', to='plandefinitions.plandefintionactoroption'),
        ),
    ]
