# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('coverageeligibilityrequests', '0001_initial'),
        ('coverages', '0002_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_enterer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='facility',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_facility', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_insurer', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_priority', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='service_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_service_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_event_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_event', to='coverageeligibilityrequests.coverageeligibilityrequestevent'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestinsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_insurance', to='coverageeligibilityrequests.coverageeligibilityrequestinsurance'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='facility',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_facility', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_provider', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_item', to='coverageeligibilityrequests.coverageeligibilityrequestitem'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitemdetailreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_detail_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_item_detail', to='coverageeligibilityrequests.coverageeligibilityrequestitemdetailreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitemdiagnosis',
            name='diagnosis_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_diagnosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitemdiagnosis',
            name='diagnosis_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_item_diagnosis_reference', to='conditions.conditionreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestitem',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_item_diagnosis', to='coverageeligibilityrequests.coverageeligibilityrequestitemdiagnosis'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_provider', to='coverageeligibilityrequests.coverageeligibilityrequestproviderreference'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequest',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='coverage_eligibility_request_supporting_info', to='coverageeligibilityrequests.coverageeligibilityrequestsupportinginfo'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestsupportinginfoinformationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_supporting_info_information_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='coverageeligibilityrequestsupportinginfo',
            name='information',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='coverage_eligibility_request_supporting_info_information', to='coverageeligibilityrequests.coverageeligibilityrequestsupportinginfoinformationreference'),
        ),
    ]
