# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careplans', '0003_initial'),
        ('conditions', '0002_initial'),
        ('medicationadministrations', '0002_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='careplan',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='care_plan_supporting_info', to='base.reference'),
        ),
        migrations.AddField(
            model_name='careplanactivity',
            name='performer_activity',
            field=models.ManyToManyField(blank=True, related_name='care_plan_activity_performer_activity', to='base.codeablereference'),
        ),
        migrations.AddField(
            model_name='careplanactivity',
            name='progress',
            field=models.ManyToManyField(blank=True, related_name='care_plan_activity_progress', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='activity',
            field=models.ManyToManyField(blank=True, related_name='care_plan_activity', to='careplans.careplanactivity'),
        ),
        migrations.AddField(
            model_name='careplanaddressescodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_addresses_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='addresses',
            field=models.ManyToManyField(blank=True, related_name='care_plan_addresses', to='careplans.careplanaddressescodeablereference'),
        ),
        migrations.AddField(
            model_name='careplanaddressreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='careplanaddressreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_address_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careplanaddressreference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='careplanaddressescodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_addresses_codeable_reference', to='careplans.careplanaddressreference'),
        ),
        migrations.AddField(
            model_name='careplanbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_based_on_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='careplanbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='care_plan_based_on_identifier', to='base.identifier'),
        ),
    ]
