# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('diagnosticreports', '0003_initial'),
        ('medicationstatements', '0003_initial'),
        ('observations', '0002_initial'),
        ('procedures', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='medication_statement_part_of', to='medicationstatements.medicationstatementpartofreference'),
        ),
        migrations.AddField(
            model_name='medicationstatementreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='medicationstatementreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='medicationstatementreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='medicationstatementreasonreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_reason_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='medication_statement_reason', to='medicationstatements.medicationstatementreasonreference'),
        ),
    ]
