# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0003_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='careteamparticipantonbehalfofreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='careteamparticipantonbehalfofreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='careteamparticipantonbehalfofreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='careteamparticipant',
            name='on_behalf_of',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_team_participants_on_behalf_of', to='careteams.careteamparticipantonbehalfofreference'),
        ),
        migrations.AddField(
            model_name='careteamreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_team_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='careteamreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_team_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='careteamparticipant',
            name='member',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='care_team_participants_member', to='careteams.careteamparticipantmemberreference'),
        ),
    ]
