# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('detectedissues', '0004_initial'),
        ('procedures', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='detectedissuesubjectreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_subject_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='detectedissuesubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='detectedissue',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='detected_issue_patient', to='detectedissues.detectedissuesubjectreference'),
        ),
    ]
