# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('claims', '0001_initial'),
        ('encounters', '0001_initial'),
        ('locations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claim',
            name='encounter',
            field=models.ManyToManyField(blank=True, related_name='claim_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='facility',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_facility', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='claim',
            name='funds_reserve',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_funds_reserve', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claim',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='claim_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claim',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_insurer', to='base.organizationreference'),
        ),
    ]
