# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('careplans', '0005_initial'),
        ('claimresponses', '0005_initial'),
        ('coverages', '0002_initial'),
        ('devicedefinitions', '0001_initial'),
        ('immunizationrecommendations', '0003_immunizationrecommendationsupportingimmunizationreference_immunization_and_more'),
        ('medicationrequests', '0003_initial'),
        ('procedures', '0002_initial'),
        ('provenances', '0002_provenance_activity_provenance_authorization_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationrequestbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_based_on_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='medicationrequestbasedonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_request_based_on_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='medicationrequestinsurancereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_request_insurance_reference_claim_response', to='claimresponses.claimresponse'),
        ),
        migrations.AddField(
            model_name='medicationrequestinsurancereference',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_request_insurance_reference_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='medicationrequestperformerreference',
            name='device_definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_request_performer_reference_device_definition', to='devicedefinitions.devicedefinition'),
        ),
        migrations.AddField(
            model_name='medicationrequestprovinancereference',
            name='provenance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_request_provinance_reference_provenance', to='provenances.provenance'),
        ),
        migrations.AddField(
            model_name='medicationrequestreasonreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_request_reason_reference_procedure', to='procedures.procedure'),
        ),
    ]
