# Generated by Django 5.2 on 2025-05-02 14:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('base', '0005_initial'),
        ('chargeitems', '0004_initial'),
        ('invoices', '0003_initial'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='CharItemReference',
            new_name='ChargeItemReference',
        ),
    ]
