# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0002_initial'),
        ('base', '0003_initial'),
        ('conditions', '0001_initial'),
        ('coverages', '0001_initial'),
        ('encounters', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='account',
            name='covers',
            field=models.ManyToManyField(blank=True, related_name='accounts_covers', to='encounters.encounterepisodeofcarereference'),
        ),
        migrations.AddField(
            model_name='account',
            name='currency',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_currency', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='account',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='accounts_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='account',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_owner', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='account',
            name='service_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_service_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='account',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='accountbalance',
            name='aggregate',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_balance_aggregate', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='accountbalance',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_balance_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='accountbalance',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_balance_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='account',
            name='balance',
            field=models.ManyToManyField(blank=True, related_name='accounts_balance', to='accounts.accountbalance'),
        ),
        migrations.AddField(
            model_name='accountcoverage',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_coverage_coverage', to='coverages.coverage'),
        ),
        migrations.AddField(
            model_name='account',
            name='coverage',
            field=models.ManyToManyField(blank=True, related_name='accounts_coverage', to='accounts.accountcoverage'),
        ),
        migrations.AddField(
            model_name='accountdiagnosis',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_diagnosis_condition', to='conditions.conditioncodeablereference'),
        ),
        migrations.AddField(
            model_name='accountdiagnosis',
            name='package_code',
            field=models.ManyToManyField(blank=True, related_name='account_diagnosis_package_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='accountdiagnosis',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='account_diagnosis_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='account',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='accounts_diagnosis', to='accounts.accountdiagnosis'),
        ),
        migrations.AddField(
            model_name='accountguarantor',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_guarantor_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='account',
            name='guarantor',
            field=models.ManyToManyField(blank=True, related_name='accounts_guarantor', to='accounts.accountguarantor'),
        ),
    ]
