# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('goals', '0002_initial'),
        ('medicationrequests', '0001_initial'),
        ('medicationstatements', '0002_initial'),
        ('nutritionintakes', '0002_initial'),
        ('nutritionorders', '0001_initial'),
        ('observations', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='goalacceptanceparticipantreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_acceptance_participant_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='goalacceptanceparticipantreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_acceptance_participant_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='goalacceptanceparticipantreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_acceptance_participant_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='goalacceptance',
            name='participant',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='goal_acceptance_participant', to='goals.goalacceptanceparticipantreference'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='nutrition_intake',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_nutrition_intake', to='nutritionintakes.nutritionintake'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='goaladdressesreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='goal_addresses_reference_observation', to='observations.observation'),
        ),
    ]
