<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>You're Invited to Join {{ organization_name }} on CareFusion365</title>
  </head>
  <body>
    <h1>Hello, {{ first_name }} {{ last_name }}!</h1>
    <p>
      You have been invited to join <strong>{{ organization_name }}</strong> on CareFusion365, our platform for seamless healthcare collaboration.
    </p>
    <p>To get started, please click the link below to accept the invitation and complete your registration:</p>
    <p>
      <a href="http://localhost:3000/invite?token={{ token }}">Accept Invitation</a>
    </p>
    <p>If the button above doesn't work, copy and paste the following link into your browser:</p>
    <p>http://localhost:3000/invite?token={{ token }}</p>
    <p>We're excited to have you on board!</p>
    <p>
      Best regards,
      <br />
      CareFusion365 Team
    </p>
  </body>
</html>
