"""Explanation of Benefits app configuration."""

from django.apps import AppConfig


class ExplanationofbenefitsConfig(AppConfig):
    """Explanation of Benefits app configuration."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.explanationofbenefits"
    verbose_name = "Explanation of Benefits"
