# Generated by Django 5.2.1 on 2025-06-30 22:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0005_alter_accountcoverage_coverage'),
        ('careteams', '0004_initial'),
        ('encounters', '0004_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='encounter',
            name='account',
            field=models.ManyToManyField(blank=True, related_name='encounter_account', to='accounts.accountreference'),
        ),
        migrations.AlterField(
            model_name='encounter',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='encounter_care_team', to='careteams.careteamreference'),
        ),
    ]
