# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('flags', '0003_initial'),
        ('observations', '0002_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('riskassessments', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='flagsubjectreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='flag',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject', to='flags.flagsubjectreference'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='flagsupportinginforeference',
            name='risk_assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_supporting_info_reference_risk_assessment', to='riskassessments.riskassessment'),
        ),
        migrations.AddField(
            model_name='flag',
            name='supporting_info',
            field=models.ManyToManyField(related_name='flag_supports', to='flags.flagsupportinginforeference'),
        ),
    ]
