# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('documentreferences', '0005_initial'),
        ('riskassessments', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='riskassessmentreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='risk_assessment_reason_references_document_reference', to='documentreferences.documentreference'),
        ),
    ]
