# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointments', '0004_initial'),
        ('base', '0005_initial'),
        ('documentreferences', '0004_initial'),
        ('encounters', '0003_initial'),
        ('episodeofcares', '0002_initial'),
        ('servicerequests', '0001_initial'),
        ('supplyrequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='supply_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_supply_request', to='supplyrequests.supplyrequest'),
        ),
        migrations.AddField(
            model_name='documentreferencebasedonreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_based_on_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='documentreference',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='document_reference_based_on', to='documentreferences.documentreferencebasedonreference'),
        ),
        migrations.AddField(
            model_name='documentreferencecodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_codeable_references_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='documentreferencecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_codeable_references_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='documentreferencecontent',
            name='attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_contents_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='documentreference',
            name='content',
            field=models.ManyToManyField(blank=True, related_name='document_reference_contents', to='documentreferences.documentreferencecontent'),
        ),
        migrations.AddField(
            model_name='documentreferencecontentprofile',
            name='value_coding',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_content_profiles_value_coding', to='base.coding'),
        ),
        migrations.AddField(
            model_name='documentreferencecontent',
            name='profile',
            field=models.ManyToManyField(blank=True, related_name='document_reference_contents_profile', to='documentreferences.documentreferencecontentprofile'),
        ),
        migrations.AddField(
            model_name='documentreferencecontextreference',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_context_reference_appointment', to='appointments.appointment'),
        ),
        migrations.AddField(
            model_name='documentreferencecontextreference',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_context_reference_encounter', to='encounters.encounter'),
        ),
        migrations.AddField(
            model_name='documentreferencecontextreference',
            name='episode_of_care',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_context_reference_episode_of_care', to='episodeofcares.episodeofcare'),
        ),
        migrations.AddField(
            model_name='documentreferencecontextreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_context_references_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='documentreference',
            name='context',
            field=models.ManyToManyField(blank=True, related_name='document_reference_contexts', to='documentreferences.documentreferencecontextreference'),
        ),
        migrations.AddField(
            model_name='documentreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_references_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='documentreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_references_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='documentreferencerelatesto',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_relates_tos_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='documentreferencerelatesto',
            name='target',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_relates_tos_target', to='documentreferences.documentreferencereference'),
        ),
        migrations.AddField(
            model_name='documentreference',
            name='relates_to',
            field=models.ManyToManyField(blank=True, related_name='document_reference_relates_tos', to='documentreferences.documentreferencerelatesto'),
        ),
    ]
