# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointments', '0001_initial'),
        ('base', '0001_initial'),
        ('healthcareservices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointment',
            name='appointment_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='cancellation_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='appointment_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='klass',
            field=models.ManyToManyField(blank=True, related_name='appointment_class', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='appointment_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='appointment_priority', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='requested_period',
            field=models.ManyToManyField(blank=True, related_name='appointment_requested_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='service_category',
            field=models.ManyToManyField(blank=True, related_name='service_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='appointment',
            name='service_type',
            field=models.ManyToManyField(blank=True, related_name='appointment_service_type', to='healthcareservices.healthcareservicecodeablereference'),
        ),
    ]
