# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('adverseevents', '0001_initial'),
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='adverseevent',
            name='category',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='cause_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_cause_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='effect_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_effect_period', to='base.period'),
        ),
    ]
