# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('activitydefinitions', '0009_initial'),
        ('base', '0005_initial'),
        ('plandefinitions', '0003_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActivityPlanDefinitionReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('activity_definition', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_plan_definition_reference_activity_definition', to='activitydefinitions.activitydefinition')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_plan_definition_reference_identifier', to='base.identifier')),
                ('plan_definition', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_plan_definition_reference_plan_definition', to='plandefinitions.plandefinition')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
