# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('medicationstatements', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='information_source',
            field=models.ManyToManyField(blank=True, related_name='medication_statement_information_source', to='medicationstatements.medicationstatementinformationsourcereference'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
    ]
