# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('biologicallyderivedproductdispenses', '0001_initial'),
        ('locations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='biologicallyderivedproductdispense_based_on', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='destination',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_destination', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='biologicallyderivedproductdispense_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_location', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='match_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_match_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='biologicallyderivedproductdispense_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='original_relationship_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_original_relationship_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispenseperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_performer_actor', to='practitioners.practitionerreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispenseperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='biologicallyderivedproductdispense_performer', to='biologicallyderivedproductdispenses.biologicallyderivedproductdispenseperformer'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispensereference',
            name='biologically_derived_product_dispense',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_reference_biologicallyderivedproductdispense', to='biologicallyderivedproductdispenses.biologicallyderivedproductdispense'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispensereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='biologicallyderivedproductdispense_part_of', to='biologicallyderivedproductdispenses.biologicallyderivedproductdispensereference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductdispense',
            name='product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='biologicallyderivedproductdispense_product', to='biologicallyderivedproductdispenses.biologicallyderivedproductdispensereference'),
        ),
    ]
