# Generated by Django 5.2 on 2025-05-05 14:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('supplydeliveries', '0001_initial'),
        ('supplyrequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='supplydelivery',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='supply_delivery_based_on', to='supplyrequests.supplyrequestreference'),
        ),
    ]
