# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
        ('devices', '0001_initial'),
        ('organizations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='signatureonbehalfofreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='signature_on_behalf_of_reference_organization', to='organizations.organization'),
        ),
    ]
