# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0003_initial'),
        ('groups', '0003_initial'),
        ('nutritionintakes', '0002_initial'),
        ('nutritionproducts', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionintakebasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_based_on', to='nutritionintakes.nutritionintakebasedonreference'),
        ),
        migrations.AddField(
            model_name='nutritionintakecodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitem',
            name='not_consumed_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_not_consumed_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitem',
            name='nutrition_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_nutrition_product', to='nutritionproducts.nutritionproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitem',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='nutrition_item',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_nutrition_item', to='nutritionintakes.nutritionintakenutritionitem'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemconsumeditem',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_consumed_item_amount', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemconsumeditem',
            name='rate_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_consumed_item_rate_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemconsumeditem',
            name='rate_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_consumed_item_rate_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemconsumeditem',
            name='schedule',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_consumed_item_schedule', to='base.timing'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitem',
            name='consumed_item',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_nutrition_item_consumed_item', to='nutritionintakes.nutritionintakenutritionitemconsumeditem'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemtotalintake',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_total_intake_amount', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemtotalintake',
            name='energy',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_total_intake_energy', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemtotalintake',
            name='nutrient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_nutrition_item_total_intake_nutrient', to='substances.substancecodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionintakenutritionitemconsumeditem',
            name='total_intake',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_nutrition_item_consumed_item_total_intake', to='nutritionintakes.nutritionintakenutritionitemtotalintake'),
        ),
        migrations.AddField(
            model_name='nutritionintakepartofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_part_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionintakepartofreference',
            name='nutrition_intake',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_part_of_reference_nutrition_intake', to='nutritionintakes.nutritionintake'),
        ),
        migrations.AddField(
            model_name='nutritionintakepartofreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_part_of_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='nutritionintakepartofreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_part_of_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_part_of', to='nutritionintakes.nutritionintakepartofreference'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_reference_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_performer', to='nutritionintakes.nutritionintakeperformer'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='nutritionintakeperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_performer_reference_actor', to='nutritionintakes.nutritionintakeperformeractorreference'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reason_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='nutrition_intake_reason_code', to='nutritionintakes.nutritionintakereasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='nutritionintakereasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_codeable_reference_reference', to='nutritionintakes.nutritionintakereasonreference'),
        ),
        migrations.AddField(
            model_name='nutritionintakereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionintakereference',
            name='nutrition_intake',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reference_nutrition_intake', to='nutritionintakes.nutritionintake'),
        ),
        migrations.AddField(
            model_name='nutritionintakecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_codeable_reference_reference', to='nutritionintakes.nutritionintakereference'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='nutritionintakereportedreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='nutritionintake',
            name='reported_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_reported_reference', to='nutritionintakes.nutritionintakereportedreference'),
        ),
    ]
