# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('activitydefinitions', '0004_initial'),
        ('devicedefinitions', '0001_initial'),
        ('devices', '0001_initial'),
        ('endpoints', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_device_reference_idevice', to='devices.device'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='device_definition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_device_definition_reference_device_definition', to='devicedefinitions.devicedefinition'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='endpoint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_endpoint', to='endpoints.endpoint'),
        ),
    ]
