# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BiologicallyDerivedProductCollection',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('collected_date_time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BiologicallyDerivedProductProperty',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value_boolean', models.BooleanField(null=True)),
                ('value_integer', models.IntegerField(null=True)),
                ('value_string', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BiologicallyDerivedProductReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BiologicallyDerivedProduct',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('division', models.CharField(max_length=255, null=True)),
                ('expiration_date', models.DateTimeField(null=True)),
                ('biological_source_event', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_biological_source_event', to='base.identifier')),
                ('identifier', models.ManyToManyField(blank=True, related_name='biologically_derived_products_identifier', to='base.identifier')),
                ('processing_facility', models.ManyToManyField(blank=True, related_name='biologically_derived_products_processing_faciality', to='base.organizationreference')),
                ('product_category', models.ManyToManyField(blank=True, related_name='biologically_derived_products_product_category', to='base.codeableconcept')),
                ('product_code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_product_code', to='base.codeableconcept')),
                ('product_status', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_product_status', to='base.coding')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
