# Generated by Django 5.2 on 2025-05-05 14:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allergyintolerances', '0006_allergyintolerancereference'),
        ('nutritionorders', '0003_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='nutritionorder',
            name='allergy_intolerance',
            field=models.ManyToManyField(blank=True, to='allergyintolerances.allergyintolerancereference'),
        ),
    ]
