# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('careplans', '0003_initial'),
        ('encounters', '0002_initial'),
        ('locations', '0001_initial'),
        ('medicationdispenses', '0001_initial'),
        ('medicationrequests', '0001_initial'),
        ('medications', '0001_initial'),
        ('provenances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationdispense',
            name='authorizing_prescription',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_authorizing_prescription', to='medicationrequests.medicationrequestreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='based_on',
            field=models.ManyToManyField(blank=True, to='careplans.careplanreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='category',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='days_supply',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_days_supply', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='destination',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_destination', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='event_history',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_event_history', to='provenances.provenance'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_dispense_location', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='medication_dispense_medication', to='medications.medicationcodeablereference'),
        ),
        migrations.AddField(
            model_name='medicationdispense',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='medication_dispense_note', to='base.annotation'),
        ),
    ]
