# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('devices', '0001_initial'),
        ('invoices', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoice',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='total_gross',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_total_gross', to='base.money'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='total_net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_total_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='total_price_component',
            field=models.ManyToManyField(blank=True, related_name='invoice_total_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='invoicelineitem',
            name='charge_item_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_line_item_charge_item_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='invoicelineitem',
            name='price_component',
            field=models.ManyToManyField(blank=True, related_name='invoice_line_item_price_component', to='base.monetarycomponent'),
        ),
        migrations.AddField(
            model_name='invoicelineitem',
            name='service_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_line_item_service_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='line_item',
            field=models.ManyToManyField(blank=True, related_name='invoice_line_item', to='invoices.invoicelineitem'),
        ),
        migrations.AddField(
            model_name='invoiceparticipant',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_participant_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='participant',
            field=models.ManyToManyField(blank=True, related_name='invoice_participant', to='invoices.invoiceparticipant'),
        ),
        migrations.AddField(
            model_name='invoiceparticipantactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_participant_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='invoiceparticipantactorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_participant_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='invoiceparticipantactorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_participant_actor_reference_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='invoiceparticipantactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='invoice_participant_actor_reference_patient', to='patients.patient'),
        ),
    ]
