# Generated by Django 5.2.1 on 2025-07-21 00:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('slots', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slot',
            name='status',
            field=models.CharField(choices=[('free', 'Free'), ('busy', 'Busy'), ('busy-unavailable', 'Busy Unavailable'), ('busy-tentative', 'Busy Tentative'), ('entered-in-error', 'Entered in Error')], default='free', max_length=255),
        ),
    ]
