# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('immunizationrecommendations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunizationrecommendation',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='contraindicated_vaccine_code',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_contraindicated_vaccine_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='forecast_reason',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_forecast_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='forecast_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_recommendation_forecast_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='supporting_patient_information',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_supporting_patient_information', to='base.reference'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='target_disease',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_target_disease', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='vaccine_code',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_vaccine_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendation',
            name='recommendation',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation', to='immunizationrecommendations.immunizationrecommendationrecommendation'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendationdatecriterion',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_recommendation_date_criterion_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='date_criterion',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_recommendation_date_criterion', to='immunizationrecommendations.immunizationrecommendationrecommendationdatecriterion'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationsupportingimmunizationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_supporting_immunization_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationrecommendation',
            name='supporting_information',
            field=models.ManyToManyField(blank=True, related_name='immunization_recommendation_supporting_information', to='immunizationrecommendations.immunizationrecommendationsupportingimmunizationreference'),
        ),
    ]
