# Generated by Django 5.2 on 2025-05-06 22:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("activitydefinitions", "0010_activityplandefinitionreference"),
    ]

    operations = [
        migrations.AlterField(
            model_name="activitydefinition",
            name="kind",
            field=models.CharField(
                choices=[
                    ("appointment", "Appointment"),
                    ("care-plan", "Care Plan"),
                    ("claim", "Claim"),
                    ("communication-request", "CommunicationRequest"),
                    ("coverage-eligibility-request", "CoverageEligibilityRequest"),
                    ("device-request", "DeviceRequest"),
                    ("enrollment-request", "EnrollmentRequest"),
                    ("immunization-recommendation", "ImmunizationRecommendation"),
                    ("medication-request", "Medication Request"),
                    ("nutrition-order", "Nutrition Order"),
                    ("request-orchestration", "Request Orchestration"),
                    ("service-request", "Service Request"),
                    ("supply-request", "Supply Request"),
                    ("task", "Task"),
                    ("transport", "Transport"),
                    ("vision-prescription", "Vision Prescription"),
                ],
                max_length=255,
                null=True,
            ),
        ),
    ]
