# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('communications', '0001_initial'),
        ('encounters', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='communication',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='communication_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communication',
            name='medium',
            field=models.ManyToManyField(blank=True, related_name='communication_medium', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='communication',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='communication_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='communication',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='communication_part_of', to='base.reference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='priority',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_priority', to='base.coding'),
        ),
        migrations.AddField(
            model_name='communication',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='communication_reason_code', to='base.codeablereference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_status', to='base.coding'),
        ),
        migrations.AddField(
            model_name='communication',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_status_reason', to='base.codeableconcept'),
        ),
    ]
