# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careteams', '0003_initial'),
        ('devices', '0001_initial'),
        ('familymemberhistories', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='familymemberhistory',
            name='patient',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='sex',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_sex', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='condition',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition', to='familymemberhistories.familymemberhistorycondition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='participant',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_participant', to='familymemberhistories.familymemberhistoryparticipant'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_patient', to='patients.patient'),
        ),
    ]
