# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
        ('careplans', '0001_initial'),
        ('careteams', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='careplan',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='care_plan_care_team', to='careteams.careteamreference'),
        ),
        migrations.AddField(
            model_name='careplan',
            name='category',
            field=models.ManyToManyField(blank=True, related_name='care_plan_category', to='base.codeableconcept'),
        ),
    ]
