# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0002_initial'),
        ('devices', '0001_initial'),
        ('documentreferences', '0005_initial'),
        ('genomicstudies', '0002_initial'),
        ('groups', '0002_initial'),
        ('nutritionproducts', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
        ('tasks', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='specimen',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_specimen', to='specimens.specimenreference'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='analysis',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis', to='genomicstudies.genomicstudyanalysis'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisdevice',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_device_device', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisdevice',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_device_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='device',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_device', to='genomicstudies.genomicstudyanalysisdevice'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisinput',
            name='file',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_input_file', to='documentreferences.documentreferencereference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisinput',
            name='generated_by_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_input_generated_by_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisinput',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_input_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='input',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_input', to='genomicstudies.genomicstudyanalysisinput'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisoutput',
            name='file',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_output_file', to='documentreferences.documentreferencereference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisoutput',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_output_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='output',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_output', to='genomicstudies.genomicstudyanalysisoutput'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformer',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_performer', to='genomicstudies.genomicstudyanalysisperformer'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_performer_actor', to='genomicstudies.genomicstudyanalysisperformeractorreference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisprotocolperformedreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='procedure_task_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisprotocolperformedreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='procedure_task_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisprotocolperformedreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='procedure_task_reference_task', to='tasks.task'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='protocol_performed',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_protocol_performed', to='genomicstudies.genomicstudyanalysisprotocolperformedreference'),
        ),
        migrations.AddField(
            model_name='genomicstudybasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudybasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='genomicstudybasedonreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_based_on_reference_task', to='tasks.task'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_based_on', to='genomicstudies.genomicstudybasedonreference'),
        ),
        migrations.AddField(
            model_name='genomicstudyreference',
            name='genomic_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_reference_genomic_study', to='genomicstudies.genomicstudy'),
        ),
        migrations.AddField(
            model_name='genomicstudyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysisinput',
            name='generated_by_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_analysis_input_generated_by_reference', to='genomicstudies.genomicstudyreference'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='nutrition_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_nutrition_product', to='nutritionproducts.nutritionproduct'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='genomicstudysubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='genomicstudy',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='genomic_study_subject', to='genomicstudies.genomicstudysubjectreference'),
        ),
    ]
