{% load allauth %}

{% comment %} djlint:off {% endcomment %}
<{% if attrs.href %}a href="{{ attrs.href }}"{% else %}button{% endif %}
                      {% if attrs.form %}form="{{ attrs.form }}"{% endif %}
                      {% if attrs.id %}id="{{ attrs.id }}"{% endif %}
                      {% if attrs.name %}name="{{ attrs.name }}"{% endif %}
                      {% if attrs.type %}type="{{ attrs.type }}"{% endif %}
                      class="btn
{% if 'success' in attrs.tags %}btn-success
{% elif 'warning' in attrs.tags %}btn-warning
{% elif 'secondary' in attrs.tags %}btn-secondary
{% elif 'danger' in attrs.tags %}btn-danger
{% elif 'primary' in attrs.tags %}btn-primary
{% else %}btn-primary
{% endif %}"
>
  {% slot %}
  {% endslot %}
  </{% if attrs.href %}a{% else %}button{% endif %}>
