# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('chargeitems', '0001_initial'),
        ('encounters', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chargeitem',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='charge_item_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='charge_item_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='occurrence_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_occurrence_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='occurrence_timing',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_occurrence_timing', to='base.timing'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='override_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_override_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='performing_organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performing_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='requesting_organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_requesting_organization', to='base.organizationreference'),
        ),
    ]
