# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('claimresponses', '0004_initial'),
        ('coverages', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('supplyrequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='supply_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_supply_request', to='supplyrequests.supplyrequest'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_request', to='claimresponses.claimresponseadditemrequestreference'),
        ),
        migrations.AddField(
            model_name='claimresponseerror',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_error_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='error',
            field=models.ManyToManyField(blank=True, related_name='claim_response_error', to='claimresponses.claimresponseerror'),
        ),
        migrations.AddField(
            model_name='claimresponseevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_event_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='claim_response_event', to='claimresponses.claimresponseevent'),
        ),
        migrations.AddField(
            model_name='claimresponseinsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='claim_response_insurance', to='claimresponses.claimresponseinsurance'),
        ),
        migrations.AddField(
            model_name='claimresponseitem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item', to='claimresponses.claimresponseitem'),
        ),
        migrations.AddField(
            model_name='claimresponseitemadjudication',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_adjudication_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseitemadjudication',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_adjudication_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseitemadjudication',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_adjudication_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='claimresponseitemadjudication',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_adjudication_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseitem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseitem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail', to='claimresponses.claimresponseitemdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail_sub_detail_adjudication', to='claimresponses.claimresponseitemadjudication'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_detail_sub_detail', to='claimresponses.claimresponseitemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseitemreviewoutcome',
            name='decision',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_review_outcome_decision', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseitemreviewoutcome',
            name='pre_auth_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_review_outcome_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponseitemreviewoutcome',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='claim_response_item_review_outcome_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_detail_sub_detail_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponseitemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_detail_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponseitem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_item_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_review_outcome', to='claimresponses.claimresponseitemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='claimresponsepayment',
            name='adjustment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment_adjustment', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponsepayment',
            name='adjustment_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment_adjustment_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponsepayment',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponsepayment',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponsepayment',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='payment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payment', to='claimresponses.claimresponsepayment'),
        ),
        migrations.AddField(
            model_name='claimresponseprocessnote',
            name='language',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_process_note_language', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseprocessnote',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_process_note_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='process_note',
            field=models.ManyToManyField(blank=True, related_name='claim_response_process_note', to='claimresponses.claimresponseprocessnote'),
        ),
        migrations.AddField(
            model_name='claimresponsereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_reference_claim_response', to='claimresponses.claimresponse'),
        ),
        migrations.AddField(
            model_name='claimresponsereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseinsurance',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_insurance_claim_response', to='claimresponses.claimresponsereference'),
        ),
        migrations.AddField(
            model_name='claimresponserequestorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_requestor_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponserequestorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_requestor_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='claimresponserequestorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_requestor_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimresponserequestorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_requestor_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='requestor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_requestor', to='claimresponses.claimresponserequestorreference'),
        ),
        migrations.AddField(
            model_name='claimresponsetotal',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_total_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponsetotal',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_total_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='total',
            field=models.ManyToManyField(blank=True, related_name='claim_response_total', to='claimresponses.claimresponsetotal'),
        ),
    ]
