# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0002_initial'),
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointmentresponse',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='appointment_response_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='appointmentresponse',
            name='participant_type',
            field=models.ManyToManyField(blank=True, related_name='appointment_response_participant_type', to='base.codeableconcept'),
        ),
    ]
