# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0003_initial'),
        ('base', '0005_initial'),
        ('devices', '0001_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='accountprocedure',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_procedure_code', to='procedures.procedurecodeablereference'),
        ),
        migrations.AddField(
            model_name='accountprocedure',
            name='device',
            field=models.ManyToManyField(blank=True, related_name='account_procedure_device', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='accountprocedure',
            name='package_code',
            field=models.ManyToManyField(blank=True, related_name='account_procedure_package_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='accountprocedure',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='account_procedure_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='account',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='accounts_procedure', to='accounts.accountprocedure'),
        ),
        migrations.AddField(
            model_name='accountreference',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_reference_account', to='accounts.account'),
        ),
        migrations.AddField(
            model_name='accountreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='accountrelatedaccount',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_related_account_reference', to='accounts.accountreference'),
        ),
        migrations.AddField(
            model_name='accountrelatedaccount',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_related_account_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='account',
            name='related_account',
            field=models.ManyToManyField(blank=True, related_name='accounts_related_account', to='accounts.accountrelatedaccount'),
        ),
        migrations.AddField(
            model_name='accountsguarantorpartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_guarantor_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='accountsguarantorpartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_guarantor_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='accountsguarantorpartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_guarantor_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='accountsguarantorpartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='accounts_guarantor_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='accountguarantor',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_guarantor_party', to='accounts.accountsguarantorpartyreference'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='accountsubjectreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='account_subject_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='account',
            name='subject',
            field=models.ManyToManyField(blank=True, related_name='accounts_subject', to='accounts.accountsubjectreference'),
        ),
    ]
