# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
        ('conditions', '0004_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0003_initial'),
        ('familymemberhistories', '0002_initial'),
        ('observations', '0002_initial'),
        ('practitionerroles', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='actor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor', to='familymemberhistories.familymemberhistoryparticipantactorreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure', to='familymemberhistories.familymemberhistoryprocedure'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_reason', to='familymemberhistories.familymemberhistoryreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_reference', to='familymemberhistories.familymemberhistoryreasonreference'),
        ),
    ]
