{% extends "base.html" %}
{% load crispy_forms_tags %}
{% block title %}
    {{ user.name }}
{% endblock title %}
{% block content %}
    <h1>{{ user.name }}</h1>
    <form class="form-horizontal"
          method="post"
          action="{% url 'users:update' %}">
        {% csrf_token %}
        {{ form|crispy }}
        <div class="control-group">
            <div class="controls">
                <button type="submit" class="btn btn-primary">Update</button>
            </div>
        </div>
    </form>
{% endblock content %}
