# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('communications', '0003_initial'),
        ('devices', '0001_initial'),
        ('endpoints', '0001_initial'),
        ('groups', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('tasks', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_task', to='tasks.task'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='communication',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='communication_based_on', to='communications.communicationbsedonreference'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='payload',
            field=models.ManyToManyField(blank=True, related_name='communication_payload', to='communications.communicationpayload'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='endpoint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_endpoint', to='endpoints.endpoint'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='communication',
            name='recipient',
            field=models.ManyToManyField(blank=True, related_name='communication_recipient', to='communications.communicationrecipientreference'),
        ),
        migrations.AddField(
            model_name='communicationreference',
            name='communication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_reference_communication', to='communications.communication'),
        ),
        migrations.AddField(
            model_name='communicationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communication',
            name='in_response_to',
            field=models.ManyToManyField(blank=True, related_name='communication_in_response_to', to='communications.communicationreference'),
        ),
        migrations.AddField(
            model_name='communicationrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='endpoint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_endpoint', to='endpoints.endpoint'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='communication',
            name='sender',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender', to='communications.communicationsenderreference'),
        ),
    ]
