# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('observationdefinitions', '0001_initial'),
        ('specimendefinitions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='observationdefinition',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_definition_specimen', to='specimendefinitions.specimendefinition'),
        ),
    ]
