# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('episodeofcares', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='episodeofcare',
            name='care_manager',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_care_manager', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_care_team', to='careteams.careteamreference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='managing_organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_managing_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_period', to='base.period'),
        ),
    ]
