# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('immunizationevaluations', '0002_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0003_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunizationrecommendationsupportingimmunizationreference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_supporting_immunization_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationsupportingimmunizationreference',
            name='immunization_evolution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_supporting_immunization_reference_immunization_evolution', to='immunizationevaluations.immunizationevaluation'),
        ),
    ]
