# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FamilyMemberHistoryCondition',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('contributed_to_death', models.BooleanField(null=True)),
                ('onset_string', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryParticipant',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryParticipantActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryProcedure',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('contributed_to_death', models.BooleanField(null=True)),
                ('performed_string', models.CharField(max_length=255, null=True)),
                ('performed_date_time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryReasonCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('partial', 'Partial'), ('completed', 'Completed'), ('entered-in-error', 'Entered in Error'), ('health-unknown', 'Health Unknown')], max_length=255)),
                ('date', models.DateTimeField(null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('born_date', models.DateTimeField(null=True)),
                ('born_string', models.CharField(max_length=255, null=True)),
                ('age_string', models.CharField(max_length=255, null=True)),
                ('estimated_age', models.BooleanField(null=True)),
                ('deceased_boolean', models.BooleanField(null=True)),
                ('deceased_date', models.DateTimeField(null=True)),
                ('deceased_string', models.CharField(max_length=255, null=True)),
                ('age_age', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_age_age', to='base.age')),
                ('age_range', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_age_range', to='base.range')),
                ('born_period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_born_period', to='base.period')),
                ('data_absent_reason', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='family_member_history_data_absent_reason', to='base.codeableconcept')),
                ('deceased_age', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_deceased_age', to='base.age')),
                ('deceased_range', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_deceased_range', to='base.range')),
                ('identifier', models.ManyToManyField(blank=True, related_name='family_member_history_identifier', to='base.identifier')),
                ('note', models.ManyToManyField(blank=True, related_name='family_member_history_note', to='base.annotation')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
