# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('claimresponses', '0005_initial'),
        ('claims', '0004_initial'),
        ('paymentnotices', '0002_initial'),
        ('paymentreconciliations', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentnotice',
            name='payment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice', to='paymentreconciliations.paymentreconciliation'),
        ),
        migrations.AddField(
            model_name='paymentnoticerequestreference',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_request_reference', to='claims.claim'),
        ),
        migrations.AddField(
            model_name='paymentnoticeresponsereference',
            name='claim_response',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='payment_notice_response_reference', to='claimresponses.claimresponse'),
        ),
    ]
