# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('medicationadministrations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationadministration',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='medication_administration_request', to='medicationrequests.medicationrequestreference'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='status_reason',
            field=models.ManyToManyField(blank=True, related_name='medication_administration_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationadministration',
            name='sub_potent_reason',
            field=models.ManyToManyField(blank=True, related_name='medication_administration_sub_potent_reason', to='base.codeableconcept'),
        ),
    ]
