# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('deviceassociations', '0001_initial'),
        ('devices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='deviceassociation',
            name='device',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='device_association_device', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='device_association_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='relationship',
            field=models.ManyToManyField(blank=True, related_name='device_association_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='status_reason',
            field=models.ManyToManyField(blank=True, related_name='device_association_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperation',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_operation_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperation',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_operation_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='deviceassociation',
            name='operation',
            field=models.ManyToManyField(blank=True, related_name='device_association_operation', to='deviceassociations.deviceassociationoperation'),
        ),
        migrations.AddField(
            model_name='deviceassociationoperationoperatorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='device_association_operation_operator_reference_identifier', to='base.identifier'),
        ),
    ]
