# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('groups', '0002_initial'),
        ('specimens', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity', to='groups.groupmemberentityreference'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_identifier', to='base.identifier'),
        ),
    ]
