# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0005_initial'),
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0002_initial'),
        ('careplans', '0005_initial'),
        ('devices', '0001_initial'),
        ('deviceusages', '0002_initial'),
        ('diagnosticreports', '0002_initial'),
        ('documentreferences', '0004_initial'),
        ('familymemberhistories', '0003_initial'),
        ('groups', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('medications', '0001_initial'),
        ('nutritionorders', '0002_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='diagnosticreport',
            name='specimen',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_specimen', to='specimens.specimenreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='Immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='careplan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_careplan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='diagnosticreportbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_based_on_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_based_on', to='diagnosticreports.diagnosticreportbasedonreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportdocumentreferencereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='document_reference_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreporteffective',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='base.period'),
        ),
        migrations.AddField(
            model_name='diagnosticreportmedia',
            name='link',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_media_document_reference', to='documentreferences.documentreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='media',
            field=models.ManyToManyField(blank=True, to='diagnosticreports.diagnosticreportmedia'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_care_plan', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='diagnosticreportperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='performer_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_performer', to='diagnosticreports.diagnosticreportperformerreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='results_interpretation',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_results_interpretation', to='diagnosticreports.diagnosticreportperformerreference'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='locations.location'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='diagnosticreportsubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='diagnostic_report_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='diagnosticreports.diagnosticreportsubjectreference'),
        ),
        migrations.AddField(
            model_name='supportinginfo',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='diagnosticreport',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='diagnostic_report_supporting_info', to='diagnosticreports.supportinginfo'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='device_usage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_device_usage', to='deviceusages.deviceusage'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='family_member_history',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_family_member_history', to='familymemberhistories.familymemberhistory'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='supportinginforeference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='supporting_info_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='supportinginfo',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='supporting_info_reference', to='diagnosticreports.supportinginforeference'),
        ),
    ]
