"""Contrib sites."""

# """To understand why this file is here, please read:
#
# http://cookiecutter-django.readthedocs.io/en/latest/faq.html#why-is-there-a-django-contrib-sites-directory-in-cookiecutter-django.
# """
