# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careplans', '0004_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunization',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='route',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_route', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='site',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_status_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='subpotent_reason',
            field=models.ManyToManyField(blank=True, related_name='immunization_subpotent_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='supporting_infortmation',
            field=models.ManyToManyField(blank=True, related_name='immunization_supporting_infortmation', to='base.reference'),
        ),
        migrations.AddField(
            model_name='immunization',
            name='vaccine_code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_vaccine_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='care_plan',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='careplans.careplan'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='immunizationbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_based_on_references', to='medicationrequests.medicationrequest'),
        ),
    ]
